@@ -46,7 +46,6 @@ class Plugin(FCPlugin, Lava):
     def __init__(self, frameworks_config):
         super().__init__()
 
-        self.identities = frameworks_config["identities"]  # lavacli identities
         self.schedule_interval = 30  # poll lava job queues every 30 seconds
         accurate_scheduler_criteria = frameworks_config.get(
             "accurate_scheduler_criteria", None
@@ -61,9 +60,6 @@ class Plugin(FCPlugin, Lava):
         self.seize_cache = {}  # cache to avoid busy seize
         self.job_tags_cache = {}  # cache to store job tags
 
-        self.device_description_prefix = "[FC]"
-        self.lava_default_description = "Created automatically by LAVA."
-
     @safe_cache
     def __update_cache(self, cache_name, job_id, value):
         self.__dict__[cache_name][job_id] += value
@@ -116,7 +112,7 @@ class Plugin(FCPlugin, Lava):
         """
 
         job_info = await self.lava_get_job_info(job_id)
-        return job_id, job_info["tags"] if job_info else None
+        return (job_id, job_info["tags"]) if job_info else None
 
     async def __get_device_tags(self, device):
         """
@@ -124,7 +120,7 @@ class Plugin(FCPlugin, Lava):
         """
 
         device_info = await self.lava_get_device_info(device)
-        return device, device_info["tags"] if device_info else None
+        return (device, device_info["tags"]) if device_info else None
 
     async def __get_device_info(self, device, clear=False):
         """
@@ -212,6 +208,10 @@ class Plugin(FCPlugin, Lava):
             logging.info("%s default in maintenance.", resource)
             return True, False
 
+        if device_info["health"] == "Retired":
+            logging.info("%s default in retired.", resource)
+            return False, False
+
         # ask default framework disconnect this resource
         logging.info("Disconnect %s from default framework", resource)
         desc = await self.__get_device_description(resource)
@@ -248,6 +248,27 @@ class Plugin(FCPlugin, Lava):
         """
 
         async def schedule_prepare():
+            # retire managed resources
+            devices_assemble = [device["hostname"] for device in devices]
+            retired_managed_resources = list(
+                set(driver.managed_resources).difference(set(devices_assemble))
+            )
+
+            for retired_managed_resource in retired_managed_resources:
+                if (
+                    driver.managed_resources_status[retired_managed_resource]
+                    != "retired"
+                ):
+                    driver.retire_resource(retired_managed_resource)
+
+            for managed_resource in driver.managed_resources:
+                if (
+                    driver.managed_resources_status[managed_resource] == "retired"
+                    and managed_resource in devices_assemble
+                ):
+                    driver.reset_resource(managed_resource)
+
+            # category managed resources
             for device in devices:
                 if device["hostname"] in driver.managed_resources and device[
                     "health"
